@@ -20,11 +20,12 @@ use App::YTDL::Helper qw( encode_list_for_lax_stdout );
 
 
 sub _my_sort {
-    my ( $sort_item, $sort_order, $h_ref, $a, $b ) = @_;
-    my @s = $sort_order eq 'Asc'
-                ? ( $h_ref->{$a}{$sort_item}, $h_ref->{$b}{$sort_item} )
-                : ( $h_ref->{$b}{$sort_item}, $h_ref->{$a}{$sort_item} );
-    if ( $sort_item eq 'view_count_raw' ) {
+    my ( $opt, $h_ref, $a, $b ) = @_;
+    my $item = $opt->{list_sort_item};
+    my @s = $opt->{list_sort_order} eq 'Asc'
+                ? ( $h_ref->{$a}{$item}, $h_ref->{$b}{$item} )
+                : ( $h_ref->{$b}{$item}, $h_ref->{$a}{$item} );
+    if ( $item eq 'view_count_raw' ) {
        $s[0] <=> $s[1] || $h_ref->{$a}{title} cmp $h_ref->{$b}{title};
     }
     else {
@@ -35,27 +36,11 @@ sub _my_sort {
 
 sub choose_videos {
     my ( $opt, $info, $tmp, $ex, $prompt ) = @_;
-    my $length_view_count = 0;
-    my $length_video_id   = 0;
-    my $has_upload_date   = 0;
-    my $has_view_count    = 0;
-    my $has_duration      = 0;
-    for my $video_id ( keys %{$tmp->{$ex}} ) {
-        $has_view_count++  if $tmp->{$ex}{$video_id}{view_count};
-        $has_upload_date++ if $tmp->{$ex}{$video_id}{upload_date} ne '0000-00-00';
-        $has_duration++    if $tmp->{$ex}{$video_id}{duration}    ne '-:--:--';
-        if ( length $video_id > $length_video_id ) {
-            $length_video_id = length $video_id;
-        }
-        if ( length $tmp->{$ex}{$video_id}{view_count} > $length_view_count ) {
-            $length_view_count = length $tmp->{$ex}{$video_id}{view_count};
-        }
-    }
     my $regexp;
-    my $back   = sprintf "%*s", $length_video_id, '   BACK';
-    my $filter = sprintf "%*s", $length_video_id, ' FILTER';
-    my $sort   = sprintf "%*s", $length_video_id, '   SORT';
-    my $enter  = sprintf "%*s", $length_video_id, '  ENTER';
+    my $back   = '       BACK';
+    my $filter = '     FILTER';
+    my $sort   = '       SORT';
+    my $enter  = '      ENTER';
     my %chosen_video_ids;
     my @last_chosen_video_ids = ();
 
@@ -65,19 +50,7 @@ sub choose_videos {
         my @tmp_video_ids;
         my $index = $#pre;
         my $mark = [];
-        my $sort_item  = $opt->{list_sort_item};
-        my $sort_order = $opt->{list_sort_order};
-        if ( $sort_item eq 'view_count_raw' && ! $has_view_count ) {
-            $sort_item = 'upload_date';
-        }
-        if ( $sort_item eq 'duration' && ! $has_duration ) {
-            $sort_item = 'upload_date';
-        }
-        if ( $sort_item eq 'upload_date' && ! $has_upload_date ) {
-            $sort_item = 'title';
-            $sort_order = 'Asc';
-        }
-        my @video_ids = sort { _my_sort( $sort_item, $sort_order, $tmp->{$ex}, $a, $b ) }  keys %{$tmp->{$ex}};
+        my @video_ids = sort { _my_sort( $opt, $tmp->{$ex}, $a, $b ) }  keys %{$tmp->{$ex}};
 
         VIDEO_ID: for my $video_id ( @video_ids ) {
             my $title = $tmp->{$ex}{$video_id}{title};
@@ -98,13 +71,13 @@ sub choose_videos {
                 ( $title ) = encode_list_for_lax_stdout( $opt, $title );
                 $title = decode( 'console_out', $title );
             }
-            $has_view_count = 0 if $opt->{list_sort_item} ne 'view_count_raw' && ! $opt->{show_view_count};
-            my $line = sprintf "%*s |", $length_video_id, $video_id;
-            $line .= sprintf " %7s", $tmp->{$ex}{$video_id}{duration}                        if $has_duration;
-            $line .= sprintf "  %10s", $tmp->{$ex}{$video_id}{upload_date}                   if $has_upload_date;
-            $line .= sprintf "  %*s", $length_view_count, $tmp->{$ex}{$video_id}{view_count} if $has_view_count;
-            $line .= sprintf "  %s", $title;
-            push @videos, $line;
+            if ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} ) {
+                push @videos, sprintf "%11s | %7s  %10s  %$opt->{length_view_count}s  %s", $video_id,
+                    $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date}, $tmp->{$ex}{$video_id}{view_count}, $title;
+            }
+            else {
+                push @videos, sprintf "%11s | %7s  %10s  %s", $video_id, $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date}, $title;
+            }
             push @tmp_video_ids, $video_id;
             $index++;
             push @$mark, $index if any { $video_id eq $_ } keys %chosen_video_ids;
