@@ -29,6 +29,7 @@ sub search_and_merge {
             if ( keys %{$info->{$ex}{$video_id}{file_name}} == 2 ) {
                 my ( $video, $audio );
                 my $height = '';
+                my $error = 0;
                 try {
                     for my $fmt ( keys %{$info->{$ex}{$video_id}{file_name}} ) {
                         my $file = $info->{$ex}{$video_id}{file_name}{$fmt};
@@ -47,8 +48,9 @@ sub search_and_merge {
                 catch {
                     say "$video_id - Merge: $_";
                     push @{$opt->{error_merge}}, $video_id;
-                    next VIDEO_ID
+                    $error = 1;
                 };
+                next VIDEO_ID if $error;
                 if ( ! $audio ) { #
                     say "$video_id: No file with audio-only stream!";
                     next VIDEO_ID;
@@ -89,7 +91,6 @@ sub search_and_merge {
                 catch {
                     say "$video_id - Merge: $_";
                     push @{$opt->{error_merge}}, $video_id;
-                    next VIDEO_ID;
                 };
             }
         }
