@@ -91,49 +91,53 @@ sub _menus {
             [ 'group_merge',     "- Merge"      ],
             [ 'group_history',   "- History"    ],
             [ 'group_list_menu', "- Video List" ],
-            [ 'group_output',    "- Appearance" ],
+            [ 'group_output',    "- Output" ],
             [ 'list_extractors', "  Extractors" ],
         ],
-        group_download => [
-            [ 'useragent',      "- UserAgent"        ],
-            [ 'overwrite',      "- Overwrite"        ],
-            [ 'retries',        "- Download retries" ],
-            [ 'timeout',        "- Timeout"          ],
-        ],
-        group_merge => [
-            [ 'merge_enabled',    "- Enable Merge"      ],
-            [ 'merge_overwrite',  "- ffmpeg overwrites" ],
-            [ 'merge_ext',        "- Output formats"    ],
-            [ 'merge_loglevel',   "- Verbosity"         ],
-            [ 'merged_in_files',  "- Input files"       ],
-        ],
-        group_quality => [
-            [ 'auto_quality',    "- Auto quality mode"            ],
-            [ 'print_pref_qual', "- Preferred qualities"          ],
-            [ 'pref_qual_slots', "- Slots 'preferred qualilties'" ],
-        ],
-        group_history => [
-            [ 'log_info',             "- Logging"         ],
-            [ 'max_channels',         "- Channel history" ],
-            [ 'channel_by_timestamp', "- History sort"    ],
-        ],
         group_directory => [
             [ 'video_dir',     "- Main video directory" ],
             [ 'extractor_dir', "- Extractor directory"  ],
             [ 'channel_dir',   "- Channel directory"    ],
         ],
         group_file => [
-            [ 'max_len_f_name',   "- Max filename length" ],
-            [ 'modify_timestamp', "- File timestamp"      ],
+            [ 'max_len_f_name',    "- Max filename length" ],
+            [ 'replace_spaces',    "- Replace spaces"      ],
+            [ 'sanitize_filename', "- Sanitize filename"   ],
+            [ 'modify_timestamp',  "- File timestamp"      ],
         ],
+        group_quality => [
+            [ 'auto_quality',    "- Auto quality mode"            ],
+            [ 'print_pref_qual', "- Preferred qualities"          ],
+            [ 'pref_qual_slots', "- Slots 'preferred qualilties'" ],
+        ],
+        group_download => [
+            [ 'useragent', "- UserAgent"        ],
+            [ 'overwrite', "- Overwrite"        ],
+            [ 'retries',   "- Download retries" ],
+            [ 'timeout',   "- Timeout"          ],
+        ],
+        group_merge => [
+            [ 'merge_enabled',   "- Enable Merge"      ],
+            [ 'merge_overwrite', "- ffmpeg overwrites" ],
+            [ 'merge_ext',       "- Output formats"    ],
+            [ 'merge_loglevel',  "- Verbosity"         ],
+            [ 'merged_in_files', "- Input files"       ],
+        ],
+        group_history => [
+            [ 'log_info',             "- Logging"         ],
+            [ 'max_channels',         "- Channel history" ],
+            [ 'channel_by_timestamp', "- History sort"    ],
+        ],
+
         group_list_menu => [
-            [ 'list_size_idx',   "- List size"  ],
-            [ 'list_sort_item',  "- Sort order" ],
-            [ 'show_view_count', "- View count" ],
+            [ 'list_size_idx',   "- List size"       ],
+            [ 'list_sort_item',  "- Sort order"      ],
+            [ 'show_view_count', "- Show view count" ],
         ],
         group_output => [
-            [ 'max_info_width',  "- Max info width" ],
-            [ 'kb_sec_len',      "- Digits 'k/s'"   ],
+            [ 'text_unidecode', "- Unmappable characters" ],
+            [ 'max_info_width', "- Max info width"        ],
+            [ 'kb_sec_len',     "- Digits 'k/s'"          ],
         ],
     };
     return $menus;
@@ -238,71 +242,52 @@ sub set_options {
                     );
                 }
             }
-            elsif ( $choice eq "useragent" ) {
-                my $prompt = 'Set the UserAgent';
-                my $list = [
-                    [ 'UserAgent', $opt->{useragent} ]
-                ];
-                _local_readline( $opt, $choice, $prompt, $list );
-                $opt->{useragent} = 'Mozilla/5.0' if $opt->{useragent} eq '';
-                $opt->{useragent} = ''            if $opt->{useragent} eq '""';
+            elsif ( $choice eq "video_dir" ) {
+                my $prompt = 'Video directory';
+                _opt_choose_a_directory( $opt, $choice, $prompt );
             }
-            elsif ( $choice eq "overwrite" ) {
-                my $prompt = 'Overwrite files';
+            elsif ( $choice eq "extractor_dir" ) {
+                my $prompt = 'Use extractor directories';
+                my $list = [ qw( no yes ) ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "channel_dir" ) {
+                my $prompt = 'Use channel directories';
                 my $list = [
-                    'NO (append if incomplete)',
-                    'YES'
+                    'no',
+                    'if from channel or playlist',
+                    'always',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
-            elsif ( $choice eq "retries" ) {
-                my $prompt = 'Download retries';
+            elsif ( $choice eq "max_len_f_name" ) {
+                my $prompt = 'Max filename length';
                 my $digits = 3;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
-            elsif ( $choice eq "timeout" ) {
-                my $prompt = 'Connection timeout (s)';
-                my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
+            elsif ( $choice eq "replace_spaces" ) {
+                my $prompt = 'Replace spaces in filenames';
+                my $list = [ qw( no yes ) ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
-            elsif ( $choice eq "merge_enabled" ) {
-                my $prompt = 'Enable merge';
+            elsif ( $choice eq "sanitize_filename" ) {
+                my $prompt = 'Sanitize filenames';
                 my $list = [
-                    'NO',
-                    'Ask',
-                    'YES'
+                    'replace  /',
+                    'replace  / \ : " * ? < > |',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
-            elsif ( $choice eq "merge_overwrite" ) {
-                my $prompt = '"ffmpeg": overwrite files without asking?';
-                my $list = [ qw( NO YES ) ];
-                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
-            }
-            elsif ( $choice eq "merge_ext" ) {
-                my $prompt = 'Output format of merged files';
-                my $list = [ qw( mkv mp4 ogg webm flv ) ];
-                _opt_choose_from_list_value( $opt, $choice, $prompt, $list );
-            }
-            elsif ( $choice eq "merge_loglevel" ) {
-                my $prompt = '\'ffmpeg\' verbosity';
-                my $list = [ qw( error warning info ) ];
-                _opt_choose_from_list_value( $opt, $choice, $prompt, $list );
-            }
-            elsif ( $choice eq "merged_in_files" ) {
-                my $prompt = 'The merged input files:';
-                my $list = [
-                    'Keep',
-                    'Move to "' . $opt->{dir_stream_files} . '"',
-                    'Remove'
-                ];
+            elsif ( $choice eq "modify_timestamp" ) {
+                my $prompt = 'Timestamp to upload date';
+                my $list = [ qw( no yes ) ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "auto_quality" ) {
                 my $prompt = 'Auto quality';
                 my $list = [
                     'manually',
-                    'keep_list_channel',
+                    'keep_channel_playlist',
                     'keep_extractor',
                     'preferred',
                     'default',
@@ -330,9 +315,65 @@ sub set_options {
                 my $digits = 2;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
+            elsif ( $choice eq "useragent" ) {
+                my $prompt = 'Set the UserAgent';
+                my $list = [
+                    [ 'UserAgent', $opt->{useragent} ]
+                ];
+                _local_readline( $opt, $choice, $prompt, $list );
+                $opt->{useragent} = 'Mozilla/5.0' if $opt->{useragent} eq '';
+                $opt->{useragent} = ''            if $opt->{useragent} eq '""';
+            }
+            elsif ( $choice eq "overwrite" ) {
+                my $prompt = 'Overwrite files';
+                my $list = [
+                    'no (append)',
+                    'yes'
+                ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "retries" ) {
+                my $prompt = 'Download retries';
+                my $digits = 3;
+                _opt_number_range( $opt, $choice, $prompt, $digits );
+            }
+            elsif ( $choice eq "timeout" ) {
+                my $prompt = 'Connection timeout (s)';
+                my $digits = 3;
+                _opt_number_range( $opt, $choice, $prompt, $digits );
+            }
+            elsif ( $choice eq "merge_enabled" ) {
+                my $prompt = 'Enable merge';
+                my $list = [ qw( no ask yes ) ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "merge_overwrite" ) {
+                my $prompt = '"ffmpeg": overwrite files without asking?';
+                my $list = [ qw( no yes ) ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "merge_ext" ) {
+                my $prompt = 'Output format of merged files';
+                my $list = [ qw( mkv mp4 ogg webm flv ) ];
+                _opt_choose_from_list_value( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "merge_loglevel" ) {
+                my $prompt = '\'ffmpeg\' verbosity';
+                my $list = [ qw( error warning info ) ];
+                _opt_choose_from_list_value( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "merged_in_files" ) {
+                my $prompt = 'The merged input files:';
+                my $list = [
+                    'keep',
+                    'move to "' . $opt->{dir_stream_files} . '"',
+                    'remove'
+                ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
             elsif ( $choice eq "log_info" ) {
                 my $prompt = 'Enable info-logging';
-                my $list = [ qw( NO YES ) ];
+                my $list = [ qw( no yes ) ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "max_channels" ) {
@@ -343,44 +384,16 @@ sub set_options {
             elsif ( $choice eq "channel_by_timestamp" ) {
                 my $prompt = 'Sort channel history';
                 my $list = [
-                    'By name',
-                    'By timestamp'
+                    'by name',
+                    'by timestamp'
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
-            elsif ( $choice eq "video_dir" ) {
-                my $prompt = 'Video directory';
-                _opt_choose_a_directory( $opt, $choice, $prompt );
-            }
-            elsif ( $choice eq "extractor_dir" ) {
-                my $prompt = 'Use extractor directories';
-                my $list = [ qw( NO YES ) ];
-                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
-            }
-            elsif ( $choice eq "channel_dir" ) {
-                my $prompt = 'Use channel directories';
-                my $list = [
-                    'No',
-                    'If from channel or list',
-                    'Always',
-                ];
-                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
-            }
-            elsif ( $choice eq "max_len_f_name" ) {
-                my $prompt = 'Maximum filename length';
-                my $digits = 3;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
-            }
-            elsif ( $choice eq "modify_timestamp" ) {
-                my $prompt = 'Timestamp to upload date';
-                my $list = [ qw( NO YES ) ];
-                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
-            }
             elsif ( $choice eq "list_size_idx" ) {
                 my $prompt = 'Youtube videos per channel/playlist';
                 my $list = [
-                    'All',
-                    'Latest 50',
+                    'all',
+                    'latest 50',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
@@ -388,19 +401,26 @@ sub set_options {
                 set_sort_videolist( $opt );
             }
             elsif ( $choice eq "show_view_count" ) {
-                my $prompt = 'Show the view count in channel/playlist menus';
+                my $prompt = 'Show view count in list-menus';
                 my $list = [
-                    'If sorted by "view count"',
-                    'Always',
+                    'if sorted by "view count"',
+                    'always',
+                ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "text_unidecode" ) {
+                my $prompt = 'Unmappable characters';
+                my $list = [
+                    'replace with *',
+                    'use Text::Unidecode',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "max_info_width" ) {
-                my $prompt = 'Maximum Info width';
+                my $prompt = 'Max Info width';
                 my $digits = 3;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
-
             elsif ( $choice eq "kb_sec_len" ) {
                 my ( $min, $max ) = ( 3, 9 );
                 my $prompt = 'Digits for "k/s" (download speed)';
@@ -455,7 +475,7 @@ sub _opt_number_range {
     my $current = $opt->{$section};
     $current = insert_sep( $current );
     # Choose_a_number
-    my $choice = choose_a_number( $digits, { name => $prompt, current => $current } );
+    my $choice = choose_a_number( $digits, { name => "\"$prompt\"", current => $current } );
     return if ! defined $choice;
     $opt->{$section} = $choice eq '--' ? undef : $choice;
     $opt->{change}++;
